---
title: TogoVar API v0.9.1
language_tabs:
  - shell: Shell
  - http: HTTP
  - javascript: JavaScript
  - ruby: Ruby
  - python: Python
  - php: PHP
  - java: Java
  - go: Go
toc_footers: []
includes: []
search: true
highlight_theme: darkula
headingLevel: 2

---

<!-- Generator: Widdershins v4.0.1 -->

<h1 id="togovar-api">TogoVar API v0.9.1</h1>

> Scroll down for code samples, example requests and responses. Select a language for code samples from the tabs above or the mobile navigation menu.

TogoVar API version 0.9.1 specification

Base URLs:

* <a href="https://grch38.togovar.org/api">https://grch38.togovar.org/api</a>

<h1 id="togovar-api-search">search</h1>

## post__search_variant

> Code samples

```shell
# You can also use wget
curl -X POST https://grch38.togovar.org/api/search/variant \
  -H 'Content-Type: application/json' \
  -H 'Accept: application/json'

```

```http
POST https://grch38.togovar.org/api/search/variant HTTP/1.1
Host: grch38.togovar.org
Content-Type: application/json
Accept: application/json

```

```javascript
const inputBody = '{
  "query": {
    "type": {
      "relation": "eq",
      "terms": [
        "ins",
        "del",
        "indel"
      ]
    }
  }
}';
const headers = {
  'Content-Type':'application/json',
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/search/variant',
{
  method: 'POST',
  body: inputBody,
  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Content-Type' => 'application/json',
  'Accept' => 'application/json'
}

result = RestClient.post 'https://grch38.togovar.org/api/search/variant',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Content-Type': 'application/json',
  'Accept': 'application/json'
}

r = requests.post('https://grch38.togovar.org/api/search/variant', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Content-Type' => 'application/json',
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('POST','https://grch38.togovar.org/api/search/variant', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/search/variant");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("POST");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Content-Type": []string{"application/json"},
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("POST", "https://grch38.togovar.org/api/search/variant", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`POST /search/variant`

> Body parameter

```json
{
  "query": {
    "type": {
      "relation": "eq",
      "terms": [
        "ins",
        "del",
        "indel"
      ]
    }
  }
}
```

<h3 id="post__search_variant-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|stat|query|integer|false|If set to `0`, do not collect statistics|
|data|query|integer|false|If set to `0`, do not return result records|
|body|body|object|false|Schema for searching variant|
|» version|body|string|false|(Optional) Set version number if you would like to use old version.|
|» formatter|body|string|false|(Optional) Formatter for response data.|
|» query|body|any|false|none|
|»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»» id|body|[string]|true|none|
|»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»» location|body|object|true|none|
|»»»» chromosome|body|string|true|chromosome name|
|»»»» position|body|any|true|none|
|»»»»» *anonymous*|body|integer|false|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»»» *anonymous*|body|object|false|Both-closed<br/>(a, b) = {x | a &le; x &le; b}|
|»»»»»»» gte|body|number|true|none|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Both-open<br/>(a, b) = {x | a &lt; x &lt; b}|
|»»»»»»» gt|body|number|true|none|
|»»»»»»» lt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-open, right-closed<br/>(a, b) = {x | a &lt; x &le; b}|
|»»»»»»» gt|body|number|true|none|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-closed, right-open<br/>(a, b) = {x | a &le; x &lt; b}|
|»»»»»»» gte|body|number|true|none|
|»»»»»»» lt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-closed, right-unbounded<br/>(a, +&infin;) = {x | x &ge; a}|
|»»»»»»» gte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-open, right-unbounded<br/>(a, +&infin;) = {x | x &gt; a}|
|»»»»»»» gt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Right-closed, left-unbounded<br/>(-&infin;, b) = {x | x &le; b}|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Right-open, left-unbounded<br/>(-&infin;, b) = {x | x &lt; b}|
|»»»»»»» lt|body|number|true|none|
|»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»» type|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»» consequence|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»» frequency|body|object|true|none|
|»»»» *anonymous*|body|object|false|none|
|»»»»» dataset|body|[Dataset](#schemadataset)|false|none|
|»»»»»» name|body|string|true|Available values|
|»»»»» frequency|body|any|true|Available keys|
|»»»»» filtered|body|boolean|false|if `true`, exclude variants with a FILTER flag other than PASS|
|»»»» *anonymous*|body|object|false|none|
|»»»»» dataset|body|[Dataset](#schemadataset)|false|none|
|»»»»» count|body|any|true|Available keys|
|»»»»» filtered|body|boolean|false|if `true`, exclude variants with a FILTER flag other than PASS|
|»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»» significance|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»»»» source|body|[string]|false|none|
|»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»» sift|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»» polyphen|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»» alphamissense|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»» gene|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[integer]|true|none|
|»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»» disease|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»»»» sub_concepts|body|boolean|false|Include diseases of subordinate concepts in the Mondo Disease Ontology (default: true)|
|»»»» source|body|[string]|false|none|
|»» *anonymous*|body|[And](#schemaand)|false|none|
|»»» and|body|[oneOf]|true|none|
|»»»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»»» *anonymous*|body|[And](#schemaand)|false|none|
|»»»» *anonymous*|body|[Or](#schemaor)|false|none|
|»»»»» or|body|[oneOf]|true|none|
|»»»»»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»»»»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»»»»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»»»»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»»»»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»»»»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»»»»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»»»»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»»»»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»»»»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»»»»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»»»»» *anonymous*|body|[And](#schemaand)|false|none|
|»»»»»» *anonymous*|body|[Or](#schemaor)|false|none|
|»»»»»» *anonymous*|body|any|false|none|
|»»»» *anonymous*|body|any|false|none|
|»» *anonymous*|body|[Or](#schemaor)|false|none|
|» limit|body|integer|false|(Optional) Default is 100.|
|» offset|body|any|false|none|
|»» *anonymous*|body|integer|false|none|
|»» *anonymous*|body|array|false|Set [{chromosome}, {position}, {reference}, {alternative}] in case you would like to paginate over 10,000 records. {reference} and {alternative} can be omitted.|
|» column|body|[string]|false|This option is only valid for the download API.|

#### Detailed descriptions

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»»»» name**: Available values
* `gem_j_wga` - [GEM Japan Whole Genome Aggregation (GEM-J WGA) Panel](https://togovar.org/doc/datasets/gem_j_wga)
* `jga_wgs` - ** DDBJ account required **
* `jga_wes` - [Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_wes)
* `jga_snp` - [SNP-chip data in the NBDC Human Database/Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_snp)
* `tommo` - [ToMMo 54KJPN Allele Frequency Panel](https://jmorp.megabank.tohoku.ac.jp/downloads/tommo-54kjpn-20230626-af_snvindelall)
* `ncbn` - 
* `gnomad_genomes` - [The Genome Aggregation Database (gnomAD Genomes)](https://gnomad.broadinstitute.org)
* `gnomad_exomes` - [The Genome Aggregation Database (gnomAD Exomes)](https://gnomad.broadinstitute.org)

**»»»»» frequency**: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» count**: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

#### Enumerated Values

|Parameter|Value|
|---|---|
|stat|1|
|stat|0|
|data|1|
|data|0|
|» version|1|
|» formatter|html|
|»»»» chromosome|1|
|»»»» chromosome|2|
|»»»» chromosome|3|
|»»»» chromosome|4|
|»»»» chromosome|5|
|»»»» chromosome|6|
|»»»» chromosome|7|
|»»»» chromosome|8|
|»»»» chromosome|9|
|»»»» chromosome|10|
|»»»» chromosome|11|
|»»»» chromosome|12|
|»»»» chromosome|13|
|»»»» chromosome|14|
|»»»» chromosome|15|
|»»»» chromosome|16|
|»»»» chromosome|17|
|»»»» chromosome|18|
|»»»» chromosome|19|
|»»»» chromosome|20|
|»»»» chromosome|21|
|»»»» chromosome|22|
|»»»» chromosome|X|
|»»»» chromosome|Y|
|»»»» chromosome|MT|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|SO_0001483|
|»»»» terms|SO_0000667|
|»»»» terms|SO_0000159|
|»»»» terms|SO_1000032|
|»»»» terms|SO_1000002|
|»»»» terms|snv|
|»»»» terms|ins|
|»»»» terms|del|
|»»»» terms|indel|
|»»»» terms|sub|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|SO_0001893|
|»»»» terms|SO_0001574|
|»»»» terms|SO_0001575|
|»»»» terms|SO_0001587|
|»»»» terms|SO_0001589|
|»»»» terms|SO_0001578|
|»»»» terms|SO_0002012|
|»»»» terms|SO_0001889|
|»»»» terms|SO_0001821|
|»»»» terms|SO_0001822|
|»»»» terms|SO_0001583|
|»»»» terms|SO_0001818|
|»»»» terms|SO_0001630|
|»»»» terms|SO_0001626|
|»»»» terms|SO_0002019|
|»»»» terms|SO_0001567|
|»»»» terms|SO_0001819|
|»»»» terms|SO_0001580|
|»»»» terms|SO_0001620|
|»»»» terms|SO_0001623|
|»»»» terms|SO_0001624|
|»»»» terms|SO_0001792|
|»»»» terms|SO_0001627|
|»»»» terms|SO_0001621|
|»»»» terms|SO_0001619|
|»»»» terms|SO_0001631|
|»»»» terms|SO_0001632|
|»»»» terms|SO_0001895|
|»»»» terms|SO_0001892|
|»»»» terms|SO_0001782|
|»»»» terms|SO_0001894|
|»»»» terms|SO_0001891|
|»»»» terms|SO_0001907|
|»»»» terms|SO_0001566|
|»»»» terms|SO_0001906|
|»»»» terms|SO_0001628|
|»»»» terms|transcript_ablation|
|»»»» terms|splice_acceptor_variant|
|»»»» terms|splice_donor_variant|
|»»»» terms|stop_gained|
|»»»» terms|frameshift_variant|
|»»»» terms|stop_lost|
|»»»» terms|start_lost|
|»»»» terms|transcript_amplification|
|»»»» terms|inframe_insertion|
|»»»» terms|inframe_deletion|
|»»»» terms|missense_variant|
|»»»» terms|protein_altering_variant|
|»»»» terms|splice_region_variant|
|»»»» terms|incomplete_terminal_codon_variant|
|»»»» terms|start_retained_variant|
|»»»» terms|stop_retained_variant|
|»»»» terms|synonymous_variant|
|»»»» terms|coding_sequence_variant|
|»»»» terms|mature_miRNA_variant|
|»»»» terms|5_prime_UTR_variant|
|»»»» terms|3_prime_UTR_variant|
|»»»» terms|non_coding_transcript_exon_variant|
|»»»» terms|intron_variant|
|»»»» terms|NMD_transcript_variant|
|»»»» terms|non_coding_transcript_variant|
|»»»» terms|upstream_gene_variant|
|»»»» terms|downstream_gene_variant|
|»»»» terms|TFBS_ablation|
|»»»» terms|TFBS_amplification|
|»»»» terms|TF_binding_site_variant|
|»»»» terms|regulatory_region_ablation|
|»»»» terms|regulatory_region_amplification|
|»»»» terms|feature_elongation|
|»»»» terms|regulatory_region_variant|
|»»»» terms|feature_truncation|
|»»»» terms|intergenic_variant|
|»»»»»» name|gem_j_wga|
|»»»»»» name|jga_wgs|
|»»»»»» name|jga_wgs.jgad000670|
|»»»»»» name|jga_wgs.jgad000687|
|»»»»»» name|jga_wgs.jgad000688|
|»»»»»» name|jga_wgs.jgad000689|
|»»»»»» name|jga_wes|
|»»»»»» name|jga_snp|
|»»»»»» name|bbj_riken.mpheno1|
|»»»»»» name|bbj_riken.mpheno1.male|
|»»»»»» name|bbj_riken.mpheno1.female|
|»»»»»» name|bbj_riken.mpheno2|
|»»»»»» name|bbj_riken.mpheno2.male|
|»»»»»» name|bbj_riken.mpheno2.female|
|»»»»»» name|bbj_riken.mpheno3|
|»»»»»» name|bbj_riken.mpheno3.male|
|»»»»»» name|bbj_riken.mpheno3.female|
|»»»»»» name|bbj_riken.mpheno4|
|»»»»»» name|bbj_riken.mpheno4.male|
|»»»»»» name|bbj_riken.mpheno4.female|
|»»»»»» name|bbj_riken.mpheno5|
|»»»»»» name|bbj_riken.mpheno5.male|
|»»»»»» name|bbj_riken.mpheno5.female|
|»»»»»» name|bbj_riken.mpheno6|
|»»»»»» name|bbj_riken.mpheno6.male|
|»»»»»» name|bbj_riken.mpheno6.female|
|»»»»»» name|bbj_riken.mpheno7|
|»»»»»» name|bbj_riken.mpheno7.male|
|»»»»»» name|bbj_riken.mpheno7.female|
|»»»»»» name|bbj_riken.mpheno8|
|»»»»»» name|bbj_riken.mpheno8.male|
|»»»»»» name|bbj_riken.mpheno9|
|»»»»»» name|bbj_riken.mpheno9.female|
|»»»»»» name|bbj_riken.mpheno10|
|»»»»»» name|bbj_riken.mpheno10.female|
|»»»»»» name|bbj_riken.mpheno11|
|»»»»»» name|bbj_riken.mpheno11.female|
|»»»»»» name|bbj_riken.mpheno12|
|»»»»»» name|bbj_riken.mpheno12.female|
|»»»»»» name|bbj_riken.mpheno13|
|»»»»»» name|bbj_riken.mpheno13.male|
|»»»»»» name|bbj_riken.mpheno13.female|
|»»»»»» name|bbj_riken.mpheno14|
|»»»»»» name|bbj_riken.mpheno14.male|
|»»»»»» name|bbj_riken.mpheno14.female|
|»»»»»» name|bbj_riken.mpheno15|
|»»»»»» name|bbj_riken.mpheno15.male|
|»»»»»» name|bbj_riken.mpheno15.female|
|»»»»»» name|bbj_riken.mpheno16|
|»»»»»» name|bbj_riken.mpheno16.male|
|»»»»»» name|bbj_riken.mpheno16.female|
|»»»»»» name|bbj_riken.mpheno17|
|»»»»»» name|bbj_riken.mpheno17.male|
|»»»»»» name|bbj_riken.mpheno17.female|
|»»»»»» name|bbj_riken.mpheno18|
|»»»»»» name|bbj_riken.mpheno18.male|
|»»»»»» name|bbj_riken.mpheno18.female|
|»»»»»» name|bbj_riken.mpheno19|
|»»»»»» name|bbj_riken.mpheno19.male|
|»»»»»» name|bbj_riken.mpheno19.female|
|»»»»»» name|bbj_riken.mpheno20|
|»»»»»» name|bbj_riken.mpheno20.male|
|»»»»»» name|bbj_riken.mpheno20.female|
|»»»»»» name|bbj_riken.mpheno21|
|»»»»»» name|bbj_riken.mpheno21.male|
|»»»»»» name|bbj_riken.mpheno21.female|
|»»»»»» name|bbj_riken.mpheno22|
|»»»»»» name|bbj_riken.mpheno22.male|
|»»»»»» name|bbj_riken.mpheno22.female|
|»»»»»» name|bbj_riken.mpheno23|
|»»»»»» name|bbj_riken.mpheno23.male|
|»»»»»» name|bbj_riken.mpheno23.female|
|»»»»»» name|bbj_riken.mpheno24|
|»»»»»» name|bbj_riken.mpheno24.male|
|»»»»»» name|bbj_riken.mpheno24.female|
|»»»»»» name|bbj_riken.mpheno25|
|»»»»»» name|bbj_riken.mpheno25.male|
|»»»»»» name|bbj_riken.mpheno25.female|
|»»»»»» name|bbj_riken.mpheno26|
|»»»»»» name|bbj_riken.mpheno26.male|
|»»»»»» name|bbj_riken.mpheno26.female|
|»»»»»» name|bbj_riken.mpheno27|
|»»»»»» name|bbj_riken.mpheno27.male|
|»»»»»» name|bbj_riken.mpheno27.female|
|»»»»»» name|bbj_riken.mpheno28|
|»»»»»» name|bbj_riken.mpheno28.male|
|»»»»»» name|bbj_riken.mpheno28.female|
|»»»»»» name|bbj_riken.mpheno29|
|»»»»»» name|bbj_riken.mpheno29.male|
|»»»»»» name|bbj_riken.mpheno29.female|
|»»»»»» name|bbj_riken.mpheno30|
|»»»»»» name|bbj_riken.mpheno30.male|
|»»»»»» name|bbj_riken.mpheno30.female|
|»»»»»» name|bbj_riken.mpheno31|
|»»»»»» name|bbj_riken.mpheno31.male|
|»»»»»» name|bbj_riken.mpheno31.female|
|»»»»»» name|bbj_riken.mpheno32|
|»»»»»» name|bbj_riken.mpheno32.male|
|»»»»»» name|bbj_riken.mpheno32.female|
|»»»»»» name|bbj_riken.mpheno33|
|»»»»»» name|bbj_riken.mpheno33.male|
|»»»»»» name|bbj_riken.mpheno33.female|
|»»»»»» name|bbj_riken.mpheno34|
|»»»»»» name|bbj_riken.mpheno34.male|
|»»»»»» name|bbj_riken.mpheno34.female|
|»»»»»» name|bbj_riken.mpheno35|
|»»»»»» name|bbj_riken.mpheno35.male|
|»»»»»» name|bbj_riken.mpheno35.female|
|»»»»»» name|bbj_riken.mpheno36|
|»»»»»» name|bbj_riken.mpheno36.male|
|»»»»»» name|bbj_riken.mpheno36.female|
|»»»»»» name|bbj_riken.mpheno37|
|»»»»»» name|bbj_riken.mpheno37.male|
|»»»»»» name|bbj_riken.mpheno37.female|
|»»»»»» name|bbj_riken.mpheno38|
|»»»»»» name|bbj_riken.mpheno38.male|
|»»»»»» name|bbj_riken.mpheno38.female|
|»»»»»» name|bbj_riken.mpheno39|
|»»»»»» name|bbj_riken.mpheno39.male|
|»»»»»» name|bbj_riken.mpheno39.female|
|»»»»»» name|bbj_riken.mpheno40|
|»»»»»» name|bbj_riken.mpheno40.male|
|»»»»»» name|bbj_riken.mpheno40.female|
|»»»»»» name|bbj_riken.mpheno41|
|»»»»»» name|bbj_riken.mpheno41.female|
|»»»»»» name|bbj_riken.mpheno42|
|»»»»»» name|bbj_riken.mpheno42.female|
|»»»»»» name|bbj_riken.mpheno44|
|»»»»»» name|bbj_riken.mpheno44.male|
|»»»»»» name|bbj_riken.mpheno44.female|
|»»»»»» name|bbj_riken.mpheno45|
|»»»»»» name|bbj_riken.mpheno45.male|
|»»»»»» name|bbj_riken.mpheno45.female|
|»»»»»» name|bbj_riken.mpheno46|
|»»»»»» name|bbj_riken.mpheno46.male|
|»»»»»» name|bbj_riken.mpheno46.female|
|»»»»»» name|tommo|
|»»»»»» name|ncbn|
|»»»»»» name|ncbn.jpn|
|»»»»»» name|ncbn.jpn.hondo|
|»»»»»» name|ncbn.jpn.ryukyu|
|»»»»»» name|ncbn.acb|
|»»»»»» name|ncbn.asw|
|»»»»»» name|ncbn.beb|
|»»»»»» name|ncbn.gbr|
|»»»»»» name|ncbn.cdx|
|»»»»»» name|ncbn.ceu|
|»»»»»» name|ncbn.clm|
|»»»»»» name|ncbn.esn|
|»»»»»» name|ncbn.fin|
|»»»»»» name|ncbn.gwd|
|»»»»»» name|ncbn.gih|
|»»»»»» name|ncbn.chb|
|»»»»»» name|ncbn.chs|
|»»»»»» name|ncbn.ibs|
|»»»»»» name|ncbn.itu|
|»»»»»» name|ncbn.jpt|
|»»»»»» name|ncbn.khv|
|»»»»»» name|ncbn.lwk|
|»»»»»» name|ncbn.msl|
|»»»»»» name|ncbn.mxl|
|»»»»»» name|ncbn.pel|
|»»»»»» name|ncbn.pur|
|»»»»»» name|ncbn.pjl|
|»»»»»» name|ncbn.stu|
|»»»»»» name|ncbn.tsi|
|»»»»»» name|ncbn.yri|
|»»»»»» name|gnomad_genomes|
|»»»»»» name|gnomad_genomes.afr|
|»»»»»» name|gnomad_genomes.ami|
|»»»»»» name|gnomad_genomes.amr|
|»»»»»» name|gnomad_genomes.asj|
|»»»»»» name|gnomad_genomes.eas|
|»»»»»» name|gnomad_genomes.fin|
|»»»»»» name|gnomad_genomes.mid|
|»»»»»» name|gnomad_genomes.nfe|
|»»»»»» name|gnomad_genomes.remaining|
|»»»»»» name|gnomad_genomes.sas|
|»»»»»» name|gnomad_exomes|
|»»»»»» name|gnomad_exomes.afr|
|»»»»»» name|gnomad_exomes.amr|
|»»»»»» name|gnomad_exomes.asj|
|»»»»»» name|gnomad_exomes.eas|
|»»»»»» name|gnomad_exomes.fin|
|»»»»»» name|gnomad_exomes.mid|
|»»»»»» name|gnomad_exomes.nfe|
|»»»»»» name|gnomad_exomes.remaining|
|»»»»»» name|gnomad_exomes.sas|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|NC|
|»»»» terms|P|
|»»»» terms|PLP|
|»»»» terms|LP|
|»»»» terms|LPLP|
|»»»» terms|DR|
|»»»» terms|ERA|
|»»»» terms|LRA|
|»»»» terms|URA|
|»»»» terms|CS|
|»»»» terms|A|
|»»»» terms|RF|
|»»»» terms|AF|
|»»»» terms|PR|
|»»»» terms|B|
|»»»» terms|LB|
|»»»» terms|CI|
|»»»» terms|AN|
|»»»» terms|O|
|»»»» terms|US|
|»»»» terms|NP|
|»»»» terms|not_in_clinvar|
|»»»» terms|pathogenic|
|»»»» terms|pathogenic_low_penetrance|
|»»»» terms|likely_pathogenic|
|»»»» terms|likely_pathogenic_low_penetrance|
|»»»» terms|drug_response|
|»»»» terms|established_risk_allele|
|»»»» terms|likely_risk_allele|
|»»»» terms|uncertain_risk_allele|
|»»»» terms|confers_sensitivity|
|»»»» terms|association|
|»»»» terms|risk_factor|
|»»»» terms|affects|
|»»»» terms|protective|
|»»»» terms|benign|
|»»»» terms|likely_benign|
|»»»» terms|conflicting_interpretations_of_pathogenicity|
|»»»» terms|association_not_found|
|»»»» terms|other|
|»»»» terms|uncertain_significance|
|»»»» terms|not_provided|
|»»»» source|clinvar|
|»»»» source|mgend|
|»»»»» *anonymous*|unassigned|
|»»»»» *anonymous*|unassigned|
|»»»»» *anonymous*|unknown|
|»»»»» *anonymous*|unassigned|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» source|clinvar|
|»»»» source|mgend|
|» column|id|
|» column|rs|
|» column|position|
|» column|ref_alt|
|» column|type|
|» column|gene|
|» column|frequency|
|» column|consequence|
|» column|condition|
|» column|sift|
|» column|polyphen|
|» column|alphamissense|

> Example responses

> 200 Response

```json
{
  "scroll": {
    "offset": 0,
    "limit": 0,
    "max_rows": 0
  },
  "statistics": {
    "total": 0,
    "filtered": 0,
    "dataset": {
      "dataset_name": 0
    },
    "type": {
      "so_term": 0
    },
    "significance": {
      "significance_key": 0
    },
    "consequence": {
      "so_term": 0
    }
  },
  "data": [
    {
      "id": "string",
      "type": "string",
      "chromosome": "string",
      "start": 0,
      "stop": 0,
      "reference": "string",
      "alternative": "string",
      "most_severe_consequence": "string",
      "sift": 0,
      "polyphen": 0,
      "existing_variations": [
        "string"
      ],
      "external_link": [
        {
          "db_name": [
            "string"
          ]
        }
      ],
      "significance": [
        {
          "condition": "string",
          "interpretations": [
            "string"
          ]
        }
      ],
      "transcripts": {
        "transcript_id": "string",
        "gene_id": "string",
        "consequence": [
          "string"
        ],
        "sift": 0,
        "polyphen": 0,
        "hgnc_id": 0,
        "symbol": {
          "source": "string",
          "label": "string"
        },
        "hgvs_p": "string",
        "hgvs_c": "string",
        "hgvs_g": "string"
      },
      "frequencies": {
        "source": "string",
        "filter": [
          "string"
        ],
        "quality": 0,
        "allele": {
          "number": 0,
          "count": 0,
          "frequency": 0
        },
        "genotype": {
          "ref_homo_count": 0,
          "hetero_count": 0,
          "alt_homo_count": 0
        }
      }
    }
  ]
}
```

> 501 Response

```
"Not implemented"
```

<h3 id="post__search_variant-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[SearchVariant](#schemasearchvariant)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

## get__search_gene

> Code samples

```shell
# You can also use wget
curl -X GET https://grch38.togovar.org/api/search/gene?term=ALDH2 \
  -H 'Accept: application/json'

```

```http
GET https://grch38.togovar.org/api/search/gene?term=ALDH2 HTTP/1.1
Host: grch38.togovar.org
Accept: application/json

```

```javascript

const headers = {
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/search/gene?term=ALDH2',
{
  method: 'GET',

  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Accept' => 'application/json'
}

result = RestClient.get 'https://grch38.togovar.org/api/search/gene',
  params: {
  'term' => 'string'
}, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Accept': 'application/json'
}

r = requests.get('https://grch38.togovar.org/api/search/gene', params={
  'term': 'ALDH2'
}, headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('GET','https://grch38.togovar.org/api/search/gene', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/search/gene?term=ALDH2");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("GET");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("GET", "https://grch38.togovar.org/api/search/gene", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`GET /search/gene`

<h3 id="get__search_gene-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|term|query|string|true|A term to search|

> Example responses

> 200 Response

```json
[
  {
    "id": 404,
    "symbol": "ALDH2",
    "name": "aldehyde dehydrogenase 2 family member",
    "alias_of": null,
    "highlight": "<em>ALDH2</em>"
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="get__search_gene-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[SearchGene](#schemasearchgene)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

## post__search_gene

> Code samples

```shell
# You can also use wget
curl -X POST https://grch38.togovar.org/api/search/gene \
  -H 'Content-Type: application/json' \
  -H 'Accept: application/json'

```

```http
POST https://grch38.togovar.org/api/search/gene HTTP/1.1
Host: grch38.togovar.org
Content-Type: application/json
Accept: application/json

```

```javascript
const inputBody = '{
  "term": "ALDH2"
}';
const headers = {
  'Content-Type':'application/json',
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/search/gene',
{
  method: 'POST',
  body: inputBody,
  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Content-Type' => 'application/json',
  'Accept' => 'application/json'
}

result = RestClient.post 'https://grch38.togovar.org/api/search/gene',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Content-Type': 'application/json',
  'Accept': 'application/json'
}

r = requests.post('https://grch38.togovar.org/api/search/gene', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Content-Type' => 'application/json',
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('POST','https://grch38.togovar.org/api/search/gene', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/search/gene");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("POST");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Content-Type": []string{"application/json"},
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("POST", "https://grch38.togovar.org/api/search/gene", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`POST /search/gene`

> Body parameter

```json
{
  "term": "ALDH2"
}
```

<h3 id="post__search_gene-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|body|body|object|false|Schema for searching gene|
|» term|body|string|true|A term to search|

> Example responses

> 200 Response

```json
[
  {
    "id": 404,
    "symbol": "ALDH2",
    "name": "aldehyde dehydrogenase 2 family member",
    "alias_of": null,
    "highlight": "<em>ALDH2</em>"
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="post__search_gene-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[SearchGene](#schemasearchgene)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

## get__search_disease

> Code samples

```shell
# You can also use wget
curl -X GET https://grch38.togovar.org/api/search/disease?term=breast%20ovarian%20cancer \
  -H 'Accept: application/json'

```

```http
GET https://grch38.togovar.org/api/search/disease?term=breast%20ovarian%20cancer HTTP/1.1
Host: grch38.togovar.org
Accept: application/json

```

```javascript

const headers = {
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/search/disease?term=breast%20ovarian%20cancer',
{
  method: 'GET',

  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Accept' => 'application/json'
}

result = RestClient.get 'https://grch38.togovar.org/api/search/disease',
  params: {
  'term' => 'string'
}, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Accept': 'application/json'
}

r = requests.get('https://grch38.togovar.org/api/search/disease', params={
  'term': 'breast ovarian cancer'
}, headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('GET','https://grch38.togovar.org/api/search/disease', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/search/disease?term=breast%20ovarian%20cancer");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("GET");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("GET", "https://grch38.togovar.org/api/search/disease", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`GET /search/disease`

<h3 id="get__search_disease-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|term|query|string|true|A term to search|

> Example responses

> 200 Response

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "highlight": "Hereditary <em>breast</em> and <em>ovarian</em> <em>cancer</em> syndrome"
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="get__search_disease-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[SearchDisease](#schemasearchdisease)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

## post__search_disease

> Code samples

```shell
# You can also use wget
curl -X POST https://grch38.togovar.org/api/search/disease \
  -H 'Content-Type: application/json' \
  -H 'Accept: application/json'

```

```http
POST https://grch38.togovar.org/api/search/disease HTTP/1.1
Host: grch38.togovar.org
Content-Type: application/json
Accept: application/json

```

```javascript
const inputBody = '{
  "term": "breast ovarian cancer"
}';
const headers = {
  'Content-Type':'application/json',
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/search/disease',
{
  method: 'POST',
  body: inputBody,
  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Content-Type' => 'application/json',
  'Accept' => 'application/json'
}

result = RestClient.post 'https://grch38.togovar.org/api/search/disease',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Content-Type': 'application/json',
  'Accept': 'application/json'
}

r = requests.post('https://grch38.togovar.org/api/search/disease', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Content-Type' => 'application/json',
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('POST','https://grch38.togovar.org/api/search/disease', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/search/disease");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("POST");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Content-Type": []string{"application/json"},
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("POST", "https://grch38.togovar.org/api/search/disease", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`POST /search/disease`

> Body parameter

```json
{
  "term": "breast ovarian cancer"
}
```

<h3 id="post__search_disease-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|body|body|object|false|Schema for searching disease|
|» term|body|string|true|A term to search|

> Example responses

> 200 Response

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "highlight": "Hereditary <em>breast</em> and <em>ovarian</em> <em>cancer</em> syndrome"
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="post__search_disease-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[SearchDisease](#schemasearchdisease)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

<h1 id="togovar-api-inspect">inspect</h1>

## get__inspect_disease

> Code samples

```shell
# You can also use wget
curl -X GET https://grch38.togovar.org/api/inspect/disease \
  -H 'Accept: application/json'

```

```http
GET https://grch38.togovar.org/api/inspect/disease HTTP/1.1
Host: grch38.togovar.org
Accept: application/json

```

```javascript

const headers = {
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/inspect/disease',
{
  method: 'GET',

  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Accept' => 'application/json'
}

result = RestClient.get 'https://grch38.togovar.org/api/inspect/disease',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Accept': 'application/json'
}

r = requests.get('https://grch38.togovar.org/api/inspect/disease', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('GET','https://grch38.togovar.org/api/inspect/disease', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/inspect/disease");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("GET");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("GET", "https://grch38.togovar.org/api/inspect/disease", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`GET /inspect/disease`

<h3 id="get__inspect_disease-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|node|query|string|false|A node ID|

> Example responses

> 200 Response

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "root": false,
    "leaf": false,
    "parents": [
      {
        "id": "MONDO_0016248",
        "cui": "CN201036",
        "label": "Familial ovarian cancer",
        "root": false
      }
    ],
    "children": [
      {
        "id": "MONDO_0012933",
        "cui": "C2675520",
        "label": "Breast-ovarian cancer, familial 2",
        "leaf": true
      }
    ]
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="get__inspect_disease-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[InspectDisease](#schemainspectdisease)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

## post__inspect_disease

> Code samples

```shell
# You can also use wget
curl -X POST https://grch38.togovar.org/api/inspect/disease \
  -H 'Content-Type: application/json' \
  -H 'Accept: application/json'

```

```http
POST https://grch38.togovar.org/api/inspect/disease HTTP/1.1
Host: grch38.togovar.org
Content-Type: application/json
Accept: application/json

```

```javascript
const inputBody = '{
  "node": "MONDO_0003582"
}';
const headers = {
  'Content-Type':'application/json',
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/inspect/disease',
{
  method: 'POST',
  body: inputBody,
  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Content-Type' => 'application/json',
  'Accept' => 'application/json'
}

result = RestClient.post 'https://grch38.togovar.org/api/inspect/disease',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Content-Type': 'application/json',
  'Accept': 'application/json'
}

r = requests.post('https://grch38.togovar.org/api/inspect/disease', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Content-Type' => 'application/json',
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('POST','https://grch38.togovar.org/api/inspect/disease', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/inspect/disease");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("POST");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Content-Type": []string{"application/json"},
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("POST", "https://grch38.togovar.org/api/inspect/disease", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`POST /inspect/disease`

> Body parameter

```json
{
  "node": "MONDO_0003582"
}
```

<h3 id="post__inspect_disease-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|pretty|query|boolean|false|If set, response body will be nicely formatted.|
|body|body|object|false|Schema for inspecting disease|
|» node|body|string|false|A node ID|

> Example responses

> 200 Response

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "root": false,
    "leaf": false,
    "parents": [
      {
        "id": "MONDO_0016248",
        "cui": "CN201036",
        "label": "Familial ovarian cancer",
        "root": false
      }
    ],
    "children": [
      {
        "id": "MONDO_0012933",
        "cui": "C2675520",
        "label": "Breast-ovarian cancer, familial 2",
        "leaf": true
      }
    ]
  }
]
```

> 501 Response

```
"Not implemented"
```

<h3 id="post__inspect_disease-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|[InspectDisease](#schemainspectdisease)|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

<h1 id="togovar-api-download">download</h1>

## post__download_variant

> Code samples

```shell
# You can also use wget
curl -X POST https://grch38.togovar.org/api/download/variant \
  -H 'Content-Type: application/json' \
  -H 'Accept: application/json'

```

```http
POST https://grch38.togovar.org/api/download/variant HTTP/1.1
Host: grch38.togovar.org
Content-Type: application/json
Accept: application/json

```

```javascript
const inputBody = '{
  "query": {
    "type": {
      "relation": "eq",
      "terms": [
        "ins",
        "del",
        "indel"
      ]
    }
  }
}';
const headers = {
  'Content-Type':'application/json',
  'Accept':'application/json'
};

fetch('https://grch38.togovar.org/api/download/variant',
{
  method: 'POST',
  body: inputBody,
  headers: headers
})
.then(function(res) {
    return res.json();
}).then(function(body) {
    console.log(body);
});

```

```ruby
require 'rest-client'
require 'json'

headers = {
  'Content-Type' => 'application/json',
  'Accept' => 'application/json'
}

result = RestClient.post 'https://grch38.togovar.org/api/download/variant',
  params: {
  }, headers: headers

p JSON.parse(result)

```

```python
import requests
headers = {
  'Content-Type': 'application/json',
  'Accept': 'application/json'
}

r = requests.post('https://grch38.togovar.org/api/download/variant', headers = headers)

print(r.json())

```

```php
<?php

require 'vendor/autoload.php';

$headers = array(
    'Content-Type' => 'application/json',
    'Accept' => 'application/json',
);

$client = new \GuzzleHttp\Client();

// Define array of request body.
$request_body = array();

try {
    $response = $client->request('POST','https://grch38.togovar.org/api/download/variant', array(
        'headers' => $headers,
        'json' => $request_body,
       )
    );
    print_r($response->getBody()->getContents());
 }
 catch (\GuzzleHttp\Exception\BadResponseException $e) {
    // handle exception or api errors.
    print_r($e->getMessage());
 }

 // ...

```

```java
URL obj = new URL("https://grch38.togovar.org/api/download/variant");
HttpURLConnection con = (HttpURLConnection) obj.openConnection();
con.setRequestMethod("POST");
int responseCode = con.getResponseCode();
BufferedReader in = new BufferedReader(
    new InputStreamReader(con.getInputStream()));
String inputLine;
StringBuffer response = new StringBuffer();
while ((inputLine = in.readLine()) != null) {
    response.append(inputLine);
}
in.close();
System.out.println(response.toString());

```

```go
package main

import (
       "bytes"
       "net/http"
)

func main() {

    headers := map[string][]string{
        "Content-Type": []string{"application/json"},
        "Accept": []string{"application/json"},
    }

    data := bytes.NewBuffer([]byte{jsonReq})
    req, err := http.NewRequest("POST", "https://grch38.togovar.org/api/download/variant", data)
    req.Header = headers

    client := &http.Client{}
    resp, err := client.Do(req)
    // ...
}

```

`POST /download/variant`

> Body parameter

```json
{
  "query": {
    "type": {
      "relation": "eq",
      "terms": [
        "ins",
        "del",
        "indel"
      ]
    }
  }
}
```

<h3 id="post__download_variant-parameters">Parameters</h3>

|Name|In|Type|Required|Description|
|---|---|---|---|---|
|body|body|object|false|Schema for searching variant|
|» version|body|string|false|(Optional) Set version number if you would like to use old version.|
|» formatter|body|string|false|(Optional) Formatter for response data.|
|» query|body|any|false|none|
|»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»» id|body|[string]|true|none|
|»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»» location|body|object|true|none|
|»»»» chromosome|body|string|true|chromosome name|
|»»»» position|body|any|true|none|
|»»»»» *anonymous*|body|integer|false|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»»» *anonymous*|body|object|false|Both-closed<br/>(a, b) = {x | a &le; x &le; b}|
|»»»»»»» gte|body|number|true|none|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Both-open<br/>(a, b) = {x | a &lt; x &lt; b}|
|»»»»»»» gt|body|number|true|none|
|»»»»»»» lt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-open, right-closed<br/>(a, b) = {x | a &lt; x &le; b}|
|»»»»»»» gt|body|number|true|none|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-closed, right-open<br/>(a, b) = {x | a &le; x &lt; b}|
|»»»»»»» gte|body|number|true|none|
|»»»»»»» lt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-closed, right-unbounded<br/>(a, +&infin;) = {x | x &ge; a}|
|»»»»»»» gte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Left-open, right-unbounded<br/>(a, +&infin;) = {x | x &gt; a}|
|»»»»»»» gt|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Right-closed, left-unbounded<br/>(-&infin;, b) = {x | x &le; b}|
|»»»»»»» lte|body|number|true|none|
|»»»»»» *anonymous*|body|object|false|Right-open, left-unbounded<br/>(-&infin;, b) = {x | x &lt; b}|
|»»»»»»» lt|body|number|true|none|
|»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»» type|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»» consequence|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»» frequency|body|object|true|none|
|»»»» *anonymous*|body|object|false|none|
|»»»»» dataset|body|[Dataset](#schemadataset)|false|none|
|»»»»»» name|body|string|true|Available values|
|»»»»» frequency|body|any|true|Available keys|
|»»»»» filtered|body|boolean|false|if `true`, exclude variants with a FILTER flag other than PASS|
|»»»» *anonymous*|body|object|false|none|
|»»»»» dataset|body|[Dataset](#schemadataset)|false|none|
|»»»»» count|body|any|true|Available keys|
|»»»»» filtered|body|boolean|false|if `true`, exclude variants with a FILTER flag other than PASS|
|»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»» significance|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»»»» source|body|[string]|false|none|
|»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»» sift|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»» polyphen|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»» alphamissense|body|object|true|none|
|»»»» score|body|any|true|none|
|»»»»» *anonymous*|body|any|false|Available keys|
|»»»»» *anonymous*|body|[string]|false|none|
|»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»» gene|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[integer]|true|none|
|»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»» disease|body|object|true|none|
|»»»» relation|body|string|true|Available values|
|»»»» terms|body|[string]|true|none|
|»»»» sub_concepts|body|boolean|false|Include diseases of subordinate concepts in the Mondo Disease Ontology (default: true)|
|»»»» source|body|[string]|false|none|
|»» *anonymous*|body|[And](#schemaand)|false|none|
|»»» and|body|[oneOf]|true|none|
|»»»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»»» *anonymous*|body|[And](#schemaand)|false|none|
|»»»» *anonymous*|body|[Or](#schemaor)|false|none|
|»»»»» or|body|[oneOf]|true|none|
|»»»»»» *anonymous*|body|[ID](#schemaid)|false|none|
|»»»»»» *anonymous*|body|[Location](#schemalocation)|false|none|
|»»»»»» *anonymous*|body|[VariantType](#schemavarianttype)|false|none|
|»»»»»» *anonymous*|body|[VariantConsequence](#schemavariantconsequence)|false|none|
|»»»»»» *anonymous*|body|[VariantFrequency](#schemavariantfrequency)|false|none|
|»»»»»» *anonymous*|body|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|
|»»»»»» *anonymous*|body|[Sift](#schemasift)|false|none|
|»»»»»» *anonymous*|body|[Polyphen](#schemapolyphen)|false|none|
|»»»»»» *anonymous*|body|[AlphaMissense](#schemaalphamissense)|false|none|
|»»»»»» *anonymous*|body|[Gene](#schemagene)|false|none|
|»»»»»» *anonymous*|body|[Disease](#schemadisease)|false|none|
|»»»»»» *anonymous*|body|[And](#schemaand)|false|none|
|»»»»»» *anonymous*|body|[Or](#schemaor)|false|none|
|»»»»»» *anonymous*|body|any|false|none|
|»»»» *anonymous*|body|any|false|none|
|»» *anonymous*|body|[Or](#schemaor)|false|none|
|» limit|body|integer|false|(Optional) Default is 100.|
|» offset|body|any|false|none|
|»» *anonymous*|body|integer|false|none|
|»» *anonymous*|body|array|false|Set [{chromosome}, {position}, {reference}, {alternative}] in case you would like to paginate over 10,000 records. {reference} and {alternative} can be omitted.|
|» column|body|[string]|false|This option is only valid for the download API.|

#### Detailed descriptions

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»»»» name**: Available values
* `gem_j_wga` - [GEM Japan Whole Genome Aggregation (GEM-J WGA) Panel](https://togovar.org/doc/datasets/gem_j_wga)
* `jga_wgs` - ** DDBJ account required **
* `jga_wes` - [Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_wes)
* `jga_snp` - [SNP-chip data in the NBDC Human Database/Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_snp)
* `tommo` - [ToMMo 54KJPN Allele Frequency Panel](https://jmorp.megabank.tohoku.ac.jp/downloads/tommo-54kjpn-20230626-af_snvindelall)
* `ncbn` - 
* `gnomad_genomes` - [The Genome Aggregation Database (gnomAD Genomes)](https://gnomad.broadinstitute.org)
* `gnomad_exomes` - [The Genome Aggregation Database (gnomAD Exomes)](https://gnomad.broadinstitute.org)

**»»»»» frequency**: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» count**: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»»» *anonymous***: Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

**»»»» relation**: Available values
 * `eq` - Equals to any of term in the list
 * `ne` - Not equals to all of term in the list

#### Enumerated Values

|Parameter|Value|
|---|---|
|» version|1|
|» formatter|html|
|»»»» chromosome|1|
|»»»» chromosome|2|
|»»»» chromosome|3|
|»»»» chromosome|4|
|»»»» chromosome|5|
|»»»» chromosome|6|
|»»»» chromosome|7|
|»»»» chromosome|8|
|»»»» chromosome|9|
|»»»» chromosome|10|
|»»»» chromosome|11|
|»»»» chromosome|12|
|»»»» chromosome|13|
|»»»» chromosome|14|
|»»»» chromosome|15|
|»»»» chromosome|16|
|»»»» chromosome|17|
|»»»» chromosome|18|
|»»»» chromosome|19|
|»»»» chromosome|20|
|»»»» chromosome|21|
|»»»» chromosome|22|
|»»»» chromosome|X|
|»»»» chromosome|Y|
|»»»» chromosome|MT|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|SO_0001483|
|»»»» terms|SO_0000667|
|»»»» terms|SO_0000159|
|»»»» terms|SO_1000032|
|»»»» terms|SO_1000002|
|»»»» terms|snv|
|»»»» terms|ins|
|»»»» terms|del|
|»»»» terms|indel|
|»»»» terms|sub|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|SO_0001893|
|»»»» terms|SO_0001574|
|»»»» terms|SO_0001575|
|»»»» terms|SO_0001587|
|»»»» terms|SO_0001589|
|»»»» terms|SO_0001578|
|»»»» terms|SO_0002012|
|»»»» terms|SO_0001889|
|»»»» terms|SO_0001821|
|»»»» terms|SO_0001822|
|»»»» terms|SO_0001583|
|»»»» terms|SO_0001818|
|»»»» terms|SO_0001630|
|»»»» terms|SO_0001626|
|»»»» terms|SO_0002019|
|»»»» terms|SO_0001567|
|»»»» terms|SO_0001819|
|»»»» terms|SO_0001580|
|»»»» terms|SO_0001620|
|»»»» terms|SO_0001623|
|»»»» terms|SO_0001624|
|»»»» terms|SO_0001792|
|»»»» terms|SO_0001627|
|»»»» terms|SO_0001621|
|»»»» terms|SO_0001619|
|»»»» terms|SO_0001631|
|»»»» terms|SO_0001632|
|»»»» terms|SO_0001895|
|»»»» terms|SO_0001892|
|»»»» terms|SO_0001782|
|»»»» terms|SO_0001894|
|»»»» terms|SO_0001891|
|»»»» terms|SO_0001907|
|»»»» terms|SO_0001566|
|»»»» terms|SO_0001906|
|»»»» terms|SO_0001628|
|»»»» terms|transcript_ablation|
|»»»» terms|splice_acceptor_variant|
|»»»» terms|splice_donor_variant|
|»»»» terms|stop_gained|
|»»»» terms|frameshift_variant|
|»»»» terms|stop_lost|
|»»»» terms|start_lost|
|»»»» terms|transcript_amplification|
|»»»» terms|inframe_insertion|
|»»»» terms|inframe_deletion|
|»»»» terms|missense_variant|
|»»»» terms|protein_altering_variant|
|»»»» terms|splice_region_variant|
|»»»» terms|incomplete_terminal_codon_variant|
|»»»» terms|start_retained_variant|
|»»»» terms|stop_retained_variant|
|»»»» terms|synonymous_variant|
|»»»» terms|coding_sequence_variant|
|»»»» terms|mature_miRNA_variant|
|»»»» terms|5_prime_UTR_variant|
|»»»» terms|3_prime_UTR_variant|
|»»»» terms|non_coding_transcript_exon_variant|
|»»»» terms|intron_variant|
|»»»» terms|NMD_transcript_variant|
|»»»» terms|non_coding_transcript_variant|
|»»»» terms|upstream_gene_variant|
|»»»» terms|downstream_gene_variant|
|»»»» terms|TFBS_ablation|
|»»»» terms|TFBS_amplification|
|»»»» terms|TF_binding_site_variant|
|»»»» terms|regulatory_region_ablation|
|»»»» terms|regulatory_region_amplification|
|»»»» terms|feature_elongation|
|»»»» terms|regulatory_region_variant|
|»»»» terms|feature_truncation|
|»»»» terms|intergenic_variant|
|»»»»»» name|gem_j_wga|
|»»»»»» name|jga_wgs|
|»»»»»» name|jga_wgs.jgad000670|
|»»»»»» name|jga_wgs.jgad000687|
|»»»»»» name|jga_wgs.jgad000688|
|»»»»»» name|jga_wgs.jgad000689|
|»»»»»» name|jga_wes|
|»»»»»» name|jga_snp|
|»»»»»» name|bbj_riken.mpheno1|
|»»»»»» name|bbj_riken.mpheno1.male|
|»»»»»» name|bbj_riken.mpheno1.female|
|»»»»»» name|bbj_riken.mpheno2|
|»»»»»» name|bbj_riken.mpheno2.male|
|»»»»»» name|bbj_riken.mpheno2.female|
|»»»»»» name|bbj_riken.mpheno3|
|»»»»»» name|bbj_riken.mpheno3.male|
|»»»»»» name|bbj_riken.mpheno3.female|
|»»»»»» name|bbj_riken.mpheno4|
|»»»»»» name|bbj_riken.mpheno4.male|
|»»»»»» name|bbj_riken.mpheno4.female|
|»»»»»» name|bbj_riken.mpheno5|
|»»»»»» name|bbj_riken.mpheno5.male|
|»»»»»» name|bbj_riken.mpheno5.female|
|»»»»»» name|bbj_riken.mpheno6|
|»»»»»» name|bbj_riken.mpheno6.male|
|»»»»»» name|bbj_riken.mpheno6.female|
|»»»»»» name|bbj_riken.mpheno7|
|»»»»»» name|bbj_riken.mpheno7.male|
|»»»»»» name|bbj_riken.mpheno7.female|
|»»»»»» name|bbj_riken.mpheno8|
|»»»»»» name|bbj_riken.mpheno8.male|
|»»»»»» name|bbj_riken.mpheno9|
|»»»»»» name|bbj_riken.mpheno9.female|
|»»»»»» name|bbj_riken.mpheno10|
|»»»»»» name|bbj_riken.mpheno10.female|
|»»»»»» name|bbj_riken.mpheno11|
|»»»»»» name|bbj_riken.mpheno11.female|
|»»»»»» name|bbj_riken.mpheno12|
|»»»»»» name|bbj_riken.mpheno12.female|
|»»»»»» name|bbj_riken.mpheno13|
|»»»»»» name|bbj_riken.mpheno13.male|
|»»»»»» name|bbj_riken.mpheno13.female|
|»»»»»» name|bbj_riken.mpheno14|
|»»»»»» name|bbj_riken.mpheno14.male|
|»»»»»» name|bbj_riken.mpheno14.female|
|»»»»»» name|bbj_riken.mpheno15|
|»»»»»» name|bbj_riken.mpheno15.male|
|»»»»»» name|bbj_riken.mpheno15.female|
|»»»»»» name|bbj_riken.mpheno16|
|»»»»»» name|bbj_riken.mpheno16.male|
|»»»»»» name|bbj_riken.mpheno16.female|
|»»»»»» name|bbj_riken.mpheno17|
|»»»»»» name|bbj_riken.mpheno17.male|
|»»»»»» name|bbj_riken.mpheno17.female|
|»»»»»» name|bbj_riken.mpheno18|
|»»»»»» name|bbj_riken.mpheno18.male|
|»»»»»» name|bbj_riken.mpheno18.female|
|»»»»»» name|bbj_riken.mpheno19|
|»»»»»» name|bbj_riken.mpheno19.male|
|»»»»»» name|bbj_riken.mpheno19.female|
|»»»»»» name|bbj_riken.mpheno20|
|»»»»»» name|bbj_riken.mpheno20.male|
|»»»»»» name|bbj_riken.mpheno20.female|
|»»»»»» name|bbj_riken.mpheno21|
|»»»»»» name|bbj_riken.mpheno21.male|
|»»»»»» name|bbj_riken.mpheno21.female|
|»»»»»» name|bbj_riken.mpheno22|
|»»»»»» name|bbj_riken.mpheno22.male|
|»»»»»» name|bbj_riken.mpheno22.female|
|»»»»»» name|bbj_riken.mpheno23|
|»»»»»» name|bbj_riken.mpheno23.male|
|»»»»»» name|bbj_riken.mpheno23.female|
|»»»»»» name|bbj_riken.mpheno24|
|»»»»»» name|bbj_riken.mpheno24.male|
|»»»»»» name|bbj_riken.mpheno24.female|
|»»»»»» name|bbj_riken.mpheno25|
|»»»»»» name|bbj_riken.mpheno25.male|
|»»»»»» name|bbj_riken.mpheno25.female|
|»»»»»» name|bbj_riken.mpheno26|
|»»»»»» name|bbj_riken.mpheno26.male|
|»»»»»» name|bbj_riken.mpheno26.female|
|»»»»»» name|bbj_riken.mpheno27|
|»»»»»» name|bbj_riken.mpheno27.male|
|»»»»»» name|bbj_riken.mpheno27.female|
|»»»»»» name|bbj_riken.mpheno28|
|»»»»»» name|bbj_riken.mpheno28.male|
|»»»»»» name|bbj_riken.mpheno28.female|
|»»»»»» name|bbj_riken.mpheno29|
|»»»»»» name|bbj_riken.mpheno29.male|
|»»»»»» name|bbj_riken.mpheno29.female|
|»»»»»» name|bbj_riken.mpheno30|
|»»»»»» name|bbj_riken.mpheno30.male|
|»»»»»» name|bbj_riken.mpheno30.female|
|»»»»»» name|bbj_riken.mpheno31|
|»»»»»» name|bbj_riken.mpheno31.male|
|»»»»»» name|bbj_riken.mpheno31.female|
|»»»»»» name|bbj_riken.mpheno32|
|»»»»»» name|bbj_riken.mpheno32.male|
|»»»»»» name|bbj_riken.mpheno32.female|
|»»»»»» name|bbj_riken.mpheno33|
|»»»»»» name|bbj_riken.mpheno33.male|
|»»»»»» name|bbj_riken.mpheno33.female|
|»»»»»» name|bbj_riken.mpheno34|
|»»»»»» name|bbj_riken.mpheno34.male|
|»»»»»» name|bbj_riken.mpheno34.female|
|»»»»»» name|bbj_riken.mpheno35|
|»»»»»» name|bbj_riken.mpheno35.male|
|»»»»»» name|bbj_riken.mpheno35.female|
|»»»»»» name|bbj_riken.mpheno36|
|»»»»»» name|bbj_riken.mpheno36.male|
|»»»»»» name|bbj_riken.mpheno36.female|
|»»»»»» name|bbj_riken.mpheno37|
|»»»»»» name|bbj_riken.mpheno37.male|
|»»»»»» name|bbj_riken.mpheno37.female|
|»»»»»» name|bbj_riken.mpheno38|
|»»»»»» name|bbj_riken.mpheno38.male|
|»»»»»» name|bbj_riken.mpheno38.female|
|»»»»»» name|bbj_riken.mpheno39|
|»»»»»» name|bbj_riken.mpheno39.male|
|»»»»»» name|bbj_riken.mpheno39.female|
|»»»»»» name|bbj_riken.mpheno40|
|»»»»»» name|bbj_riken.mpheno40.male|
|»»»»»» name|bbj_riken.mpheno40.female|
|»»»»»» name|bbj_riken.mpheno41|
|»»»»»» name|bbj_riken.mpheno41.female|
|»»»»»» name|bbj_riken.mpheno42|
|»»»»»» name|bbj_riken.mpheno42.female|
|»»»»»» name|bbj_riken.mpheno44|
|»»»»»» name|bbj_riken.mpheno44.male|
|»»»»»» name|bbj_riken.mpheno44.female|
|»»»»»» name|bbj_riken.mpheno45|
|»»»»»» name|bbj_riken.mpheno45.male|
|»»»»»» name|bbj_riken.mpheno45.female|
|»»»»»» name|bbj_riken.mpheno46|
|»»»»»» name|bbj_riken.mpheno46.male|
|»»»»»» name|bbj_riken.mpheno46.female|
|»»»»»» name|tommo|
|»»»»»» name|ncbn|
|»»»»»» name|ncbn.jpn|
|»»»»»» name|ncbn.jpn.hondo|
|»»»»»» name|ncbn.jpn.ryukyu|
|»»»»»» name|ncbn.acb|
|»»»»»» name|ncbn.asw|
|»»»»»» name|ncbn.beb|
|»»»»»» name|ncbn.gbr|
|»»»»»» name|ncbn.cdx|
|»»»»»» name|ncbn.ceu|
|»»»»»» name|ncbn.clm|
|»»»»»» name|ncbn.esn|
|»»»»»» name|ncbn.fin|
|»»»»»» name|ncbn.gwd|
|»»»»»» name|ncbn.gih|
|»»»»»» name|ncbn.chb|
|»»»»»» name|ncbn.chs|
|»»»»»» name|ncbn.ibs|
|»»»»»» name|ncbn.itu|
|»»»»»» name|ncbn.jpt|
|»»»»»» name|ncbn.khv|
|»»»»»» name|ncbn.lwk|
|»»»»»» name|ncbn.msl|
|»»»»»» name|ncbn.mxl|
|»»»»»» name|ncbn.pel|
|»»»»»» name|ncbn.pur|
|»»»»»» name|ncbn.pjl|
|»»»»»» name|ncbn.stu|
|»»»»»» name|ncbn.tsi|
|»»»»»» name|ncbn.yri|
|»»»»»» name|gnomad_genomes|
|»»»»»» name|gnomad_genomes.afr|
|»»»»»» name|gnomad_genomes.ami|
|»»»»»» name|gnomad_genomes.amr|
|»»»»»» name|gnomad_genomes.asj|
|»»»»»» name|gnomad_genomes.eas|
|»»»»»» name|gnomad_genomes.fin|
|»»»»»» name|gnomad_genomes.mid|
|»»»»»» name|gnomad_genomes.nfe|
|»»»»»» name|gnomad_genomes.remaining|
|»»»»»» name|gnomad_genomes.sas|
|»»»»»» name|gnomad_exomes|
|»»»»»» name|gnomad_exomes.afr|
|»»»»»» name|gnomad_exomes.amr|
|»»»»»» name|gnomad_exomes.asj|
|»»»»»» name|gnomad_exomes.eas|
|»»»»»» name|gnomad_exomes.fin|
|»»»»»» name|gnomad_exomes.mid|
|»»»»»» name|gnomad_exomes.nfe|
|»»»»»» name|gnomad_exomes.remaining|
|»»»»»» name|gnomad_exomes.sas|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» terms|NC|
|»»»» terms|P|
|»»»» terms|PLP|
|»»»» terms|LP|
|»»»» terms|LPLP|
|»»»» terms|DR|
|»»»» terms|ERA|
|»»»» terms|LRA|
|»»»» terms|URA|
|»»»» terms|CS|
|»»»» terms|A|
|»»»» terms|RF|
|»»»» terms|AF|
|»»»» terms|PR|
|»»»» terms|B|
|»»»» terms|LB|
|»»»» terms|CI|
|»»»» terms|AN|
|»»»» terms|O|
|»»»» terms|US|
|»»»» terms|NP|
|»»»» terms|not_in_clinvar|
|»»»» terms|pathogenic|
|»»»» terms|pathogenic_low_penetrance|
|»»»» terms|likely_pathogenic|
|»»»» terms|likely_pathogenic_low_penetrance|
|»»»» terms|drug_response|
|»»»» terms|established_risk_allele|
|»»»» terms|likely_risk_allele|
|»»»» terms|uncertain_risk_allele|
|»»»» terms|confers_sensitivity|
|»»»» terms|association|
|»»»» terms|risk_factor|
|»»»» terms|affects|
|»»»» terms|protective|
|»»»» terms|benign|
|»»»» terms|likely_benign|
|»»»» terms|conflicting_interpretations_of_pathogenicity|
|»»»» terms|association_not_found|
|»»»» terms|other|
|»»»» terms|uncertain_significance|
|»»»» terms|not_provided|
|»»»» source|clinvar|
|»»»» source|mgend|
|»»»»» *anonymous*|unassigned|
|»»»»» *anonymous*|unassigned|
|»»»»» *anonymous*|unknown|
|»»»»» *anonymous*|unassigned|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» relation|eq|
|»»»» relation|ne|
|»»»» source|clinvar|
|»»»» source|mgend|
|» column|id|
|» column|rs|
|» column|position|
|» column|ref_alt|
|» column|type|
|» column|gene|
|» column|frequency|
|» column|consequence|
|» column|condition|
|» column|sift|
|» column|polyphen|
|» column|alphamissense|

> Example responses

> 200 Response

```json
{
  "data": [
    {
      "tgv_id": "string",
      "rs": [
        "string"
      ],
      "chromosome": "string",
      "position_grch38": 0,
      "reference": "string",
      "alternate": "string",
      "type": "string",
      "gene": {
        "name": "string",
        "id": "string",
        "synonyms": [
          "string"
        ]
      },
      "consequence": [
        "string"
      ],
      "condition": [
        {}
      ],
      "sift_qualitative_prediction": "string",
      "sift_score": 0,
      "polyphen2_qualitative_prediction": "string",
      "polyphen_score": 0,
      "alphamissense_pathogenicity": "string",
      "alphamissense_score": 0,
      "jga_wgs_allele_alt": 0,
      "jga_wgs_allele_total": 0,
      "jga_wgs_alt_allele_freq": 0,
      "jga_wgs_qc_status": [
        "string"
      ],
      "jga_wes_allele_alt": 0,
      "jga_wes_allele_total": 0,
      "jga_wes_alt_allele_freq": 0,
      "jga_wes_qc_status": [
        "string"
      ],
      "jga_snp_allele_alt": 0,
      "jga_snp_allele_total": 0,
      "jga_snp_alt_allele_freq": 0,
      "jga_snp_genotype_alt_alt": 0,
      "jga_snp_genotype_ref_alt": 0,
      "jga_snp_genotype_ref_ref": 0,
      "jga_snp_qc_status": [
        "string"
      ],
      "tommo_allele_alt": 0,
      "tommo_allele_total": 0,
      "tommo_alt_allele_freq": 0,
      "tommo_qc_status": [
        "string"
      ],
      "hgvd_allele_alt": 0,
      "hgvd_allele_total": 0,
      "hgvd_alt_allele_freq": 0,
      "hgvd_qc_status": [
        "string"
      ],
      "gem_j_wga_allele_alt": 0,
      "gem_j_wga_allele_total": 0,
      "gem_j_wga_alt_allele_freq": 0,
      "gem_j_wga_qc_status": [
        "string"
      ],
      "gnomad_genomes_allele_alt": 0,
      "gnomad_genomes_allele_total": 0,
      "gnomad_genomes_alt_allele_freq": 0,
      "gnomad_genomes_qc_status": [
        "string"
      ]
    }
  ]
}
```

```
"string"
```

<h3 id="post__download_variant-responses">Responses</h3>

|Status|Meaning|Description|Schema|
|---|---|---|---|
|200|[OK](https://tools.ietf.org/html/rfc7231#section-6.3.1)|`OK`|string|
|400|[Bad Request](https://tools.ietf.org/html/rfc7231#section-6.5.1)|`Bad Request`<br/> Your query contains grammatical mistakes. See errors in the response.|[Error](#schemaerror)|
|500|[Internal Server Error](https://tools.ietf.org/html/rfc7231#section-6.6.1)|`Internal Server Error`<br/> Unexpected errors occurred.|[Error](#schemaerror)|
|501|[Not Implemented](https://tools.ietf.org/html/rfc7231#section-6.6.2)|`Not Implemented`<br/> Responder for given mime type are not implemented. Provide the correct accept header (e.g. `Accept: application/json`).|string|

<aside class="success">
This operation does not require authentication
</aside>

# Schemas

<h2 id="tocS_ID">ID</h2>
<!-- backwards compatibility -->
<a id="schemaid"></a>
<a id="schema_ID"></a>
<a id="tocSid"></a>
<a id="tocsid"></a>

```json
{
  "id": [
    "string"
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|id|[string]|true|none|none|

<h2 id="tocS_Location">Location</h2>
<!-- backwards compatibility -->
<a id="schemalocation"></a>
<a id="schema_Location"></a>
<a id="tocSlocation"></a>
<a id="tocslocation"></a>

```json
{
  "location": {
    "chromosome": "1",
    "position": 0
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|location|object|true|none|none|
|» chromosome|string|true|none|chromosome name|
|» position|any|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|integer|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[Range](#schemarange)|false|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|

#### Enumerated Values

|Property|Value|
|---|---|
|chromosome|1|
|chromosome|2|
|chromosome|3|
|chromosome|4|
|chromosome|5|
|chromosome|6|
|chromosome|7|
|chromosome|8|
|chromosome|9|
|chromosome|10|
|chromosome|11|
|chromosome|12|
|chromosome|13|
|chromosome|14|
|chromosome|15|
|chromosome|16|
|chromosome|17|
|chromosome|18|
|chromosome|19|
|chromosome|20|
|chromosome|21|
|chromosome|22|
|chromosome|X|
|chromosome|Y|
|chromosome|MT|

<h2 id="tocS_VariantType">VariantType</h2>
<!-- backwards compatibility -->
<a id="schemavarianttype"></a>
<a id="schema_VariantType"></a>
<a id="tocSvarianttype"></a>
<a id="tocsvarianttype"></a>

```json
{
  "type": {
    "relation": "eq",
    "terms": [
      "SO_0001483"
    ]
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|type|object|true|none|none|
|» relation|string|true|none|Available values<br> * `eq` - Equals to any of term in the list<br> * `ne` - Not equals to all of term in the list|
|» terms|[string]|true|none|none|

#### Enumerated Values

|Property|Value|
|---|---|
|relation|eq|
|relation|ne|

<h2 id="tocS_VariantConsequence">VariantConsequence</h2>
<!-- backwards compatibility -->
<a id="schemavariantconsequence"></a>
<a id="schema_VariantConsequence"></a>
<a id="tocSvariantconsequence"></a>
<a id="tocsvariantconsequence"></a>

```json
{
  "consequence": {
    "relation": "eq",
    "terms": [
      "SO_0001893"
    ]
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|consequence|object|true|none|none|
|» relation|string|true|none|Available values<br> * `eq` - Equals to any of term in the list<br> * `ne` - Not equals to all of term in the list|
|» terms|[string]|true|none|none|

#### Enumerated Values

|Property|Value|
|---|---|
|relation|eq|
|relation|ne|

<h2 id="tocS_VariantFrequency">VariantFrequency</h2>
<!-- backwards compatibility -->
<a id="schemavariantfrequency"></a>
<a id="schema_VariantFrequency"></a>
<a id="tocSvariantfrequency"></a>
<a id="tocsvariantfrequency"></a>

```json
{
  "frequency": {
    "dataset": {
      "name": "gem_j_wga"
    },
    "frequency": {
      "gte": 0,
      "lte": 0
    },
    "filtered": true
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|frequency|object|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|object|false|none|none|
|»» dataset|[Dataset](#schemadataset)|false|none|none|
|»» frequency|[Range](#schemarange)|true|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|
|»» filtered|boolean|false|none|if `true`, exclude variants with a FILTER flag other than PASS|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|object|false|none|none|
|»» dataset|[Dataset](#schemadataset)|false|none|none|
|»» count|[Range](#schemarange)|true|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|
|»» filtered|boolean|false|none|if `true`, exclude variants with a FILTER flag other than PASS|

<h2 id="tocS_ClinicalSignificance">ClinicalSignificance</h2>
<!-- backwards compatibility -->
<a id="schemaclinicalsignificance"></a>
<a id="schema_ClinicalSignificance"></a>
<a id="tocSclinicalsignificance"></a>
<a id="tocsclinicalsignificance"></a>

```json
{
  "significance": {
    "relation": "eq",
    "terms": [
      "NC"
    ],
    "source": [
      "clinvar"
    ]
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|significance|object|true|none|none|
|» relation|string|true|none|Available values<br> * `eq` - Equals to any of term in the list<br> * `ne` - Not equals to all of term in the list|
|» terms|[string]|true|none|none|
|» source|[string]|false|none|none|

#### Enumerated Values

|Property|Value|
|---|---|
|relation|eq|
|relation|ne|

<h2 id="tocS_Sift">Sift</h2>
<!-- backwards compatibility -->
<a id="schemasift"></a>
<a id="schema_Sift"></a>
<a id="tocSsift"></a>
<a id="tocssift"></a>

```json
{
  "sift": {
    "score": {
      "gte": 0,
      "lte": 0
    }
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|sift|object|true|none|none|
|» score|any|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[Range](#schemarange)|false|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[string]|false|none|none|

<h2 id="tocS_Polyphen">Polyphen</h2>
<!-- backwards compatibility -->
<a id="schemapolyphen"></a>
<a id="schema_Polyphen"></a>
<a id="tocSpolyphen"></a>
<a id="tocspolyphen"></a>

```json
{
  "polyphen": {
    "score": {
      "gte": 0,
      "lte": 0
    }
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|polyphen|object|true|none|none|
|» score|any|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[Range](#schemarange)|false|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[string]|false|none|none|

<h2 id="tocS_AlphaMissense">AlphaMissense</h2>
<!-- backwards compatibility -->
<a id="schemaalphamissense"></a>
<a id="schema_AlphaMissense"></a>
<a id="tocSalphamissense"></a>
<a id="tocsalphamissense"></a>

```json
{
  "alphamissense": {
    "score": {
      "gte": 0,
      "lte": 0
    }
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|alphamissense|object|true|none|none|
|» score|any|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[Range](#schemarange)|false|none|Available keys<br> * `gte` - Greater than or equal to<br> * `te` - Greater than<br> * `lte` - Less than or equal to<br> * `le` - Less than|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|»» *anonymous*|[string]|false|none|none|

<h2 id="tocS_Gene">Gene</h2>
<!-- backwards compatibility -->
<a id="schemagene"></a>
<a id="schema_Gene"></a>
<a id="tocSgene"></a>
<a id="tocsgene"></a>

```json
{
  "gene": {
    "relation": "eq",
    "terms": [
      0
    ]
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|gene|object|true|none|none|
|» relation|string|true|none|Available values<br> * `eq` - Equals to any of term in the list<br> * `ne` - Not equals to all of term in the list|
|» terms|[integer]|true|none|none|

#### Enumerated Values

|Property|Value|
|---|---|
|relation|eq|
|relation|ne|

<h2 id="tocS_Disease">Disease</h2>
<!-- backwards compatibility -->
<a id="schemadisease"></a>
<a id="schema_Disease"></a>
<a id="tocSdisease"></a>
<a id="tocsdisease"></a>

```json
{
  "disease": {
    "relation": "eq",
    "terms": [
      "string"
    ],
    "sub_concepts": true,
    "source": [
      "clinvar"
    ]
  }
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|disease|object|true|none|none|
|» relation|string|true|none|Available values<br> * `eq` - Equals to any of term in the list<br> * `ne` - Not equals to all of term in the list|
|» terms|[string]|true|none|none|
|» sub_concepts|boolean|false|none|Include diseases of subordinate concepts in the Mondo Disease Ontology (default: true)|
|» source|[string]|false|none|none|

#### Enumerated Values

|Property|Value|
|---|---|
|relation|eq|
|relation|ne|

<h2 id="tocS_Dataset">Dataset</h2>
<!-- backwards compatibility -->
<a id="schemadataset"></a>
<a id="schema_Dataset"></a>
<a id="tocSdataset"></a>
<a id="tocsdataset"></a>

```json
{
  "name": "gem_j_wga"
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|name|string|true|none|Available values<br>* `gem_j_wga` - [GEM Japan Whole Genome Aggregation (GEM-J WGA) Panel](https://togovar.org/doc/datasets/gem_j_wga)<br>* `jga_wgs` - ** DDBJ account required **<br>* `jga_wes` - [Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_wes)<br>* `jga_snp` - [SNP-chip data in the NBDC Human Database/Japanese Genotype-phenotype Archive (JGA)](https://togovar.org/doc/datasets/jga_snp)<br>* `tommo` - [ToMMo 54KJPN Allele Frequency Panel](https://jmorp.megabank.tohoku.ac.jp/downloads/tommo-54kjpn-20230626-af_snvindelall)<br>* `ncbn` - <br>* `gnomad_genomes` - [The Genome Aggregation Database (gnomAD Genomes)](https://gnomad.broadinstitute.org)<br>* `gnomad_exomes` - [The Genome Aggregation Database (gnomAD Exomes)](https://gnomad.broadinstitute.org)|

#### Enumerated Values

|Property|Value|
|---|---|
|name|gem_j_wga|
|name|jga_wgs|
|name|jga_wgs.jgad000670|
|name|jga_wgs.jgad000687|
|name|jga_wgs.jgad000688|
|name|jga_wgs.jgad000689|
|name|jga_wes|
|name|jga_snp|
|name|bbj_riken.mpheno1|
|name|bbj_riken.mpheno1.male|
|name|bbj_riken.mpheno1.female|
|name|bbj_riken.mpheno2|
|name|bbj_riken.mpheno2.male|
|name|bbj_riken.mpheno2.female|
|name|bbj_riken.mpheno3|
|name|bbj_riken.mpheno3.male|
|name|bbj_riken.mpheno3.female|
|name|bbj_riken.mpheno4|
|name|bbj_riken.mpheno4.male|
|name|bbj_riken.mpheno4.female|
|name|bbj_riken.mpheno5|
|name|bbj_riken.mpheno5.male|
|name|bbj_riken.mpheno5.female|
|name|bbj_riken.mpheno6|
|name|bbj_riken.mpheno6.male|
|name|bbj_riken.mpheno6.female|
|name|bbj_riken.mpheno7|
|name|bbj_riken.mpheno7.male|
|name|bbj_riken.mpheno7.female|
|name|bbj_riken.mpheno8|
|name|bbj_riken.mpheno8.male|
|name|bbj_riken.mpheno9|
|name|bbj_riken.mpheno9.female|
|name|bbj_riken.mpheno10|
|name|bbj_riken.mpheno10.female|
|name|bbj_riken.mpheno11|
|name|bbj_riken.mpheno11.female|
|name|bbj_riken.mpheno12|
|name|bbj_riken.mpheno12.female|
|name|bbj_riken.mpheno13|
|name|bbj_riken.mpheno13.male|
|name|bbj_riken.mpheno13.female|
|name|bbj_riken.mpheno14|
|name|bbj_riken.mpheno14.male|
|name|bbj_riken.mpheno14.female|
|name|bbj_riken.mpheno15|
|name|bbj_riken.mpheno15.male|
|name|bbj_riken.mpheno15.female|
|name|bbj_riken.mpheno16|
|name|bbj_riken.mpheno16.male|
|name|bbj_riken.mpheno16.female|
|name|bbj_riken.mpheno17|
|name|bbj_riken.mpheno17.male|
|name|bbj_riken.mpheno17.female|
|name|bbj_riken.mpheno18|
|name|bbj_riken.mpheno18.male|
|name|bbj_riken.mpheno18.female|
|name|bbj_riken.mpheno19|
|name|bbj_riken.mpheno19.male|
|name|bbj_riken.mpheno19.female|
|name|bbj_riken.mpheno20|
|name|bbj_riken.mpheno20.male|
|name|bbj_riken.mpheno20.female|
|name|bbj_riken.mpheno21|
|name|bbj_riken.mpheno21.male|
|name|bbj_riken.mpheno21.female|
|name|bbj_riken.mpheno22|
|name|bbj_riken.mpheno22.male|
|name|bbj_riken.mpheno22.female|
|name|bbj_riken.mpheno23|
|name|bbj_riken.mpheno23.male|
|name|bbj_riken.mpheno23.female|
|name|bbj_riken.mpheno24|
|name|bbj_riken.mpheno24.male|
|name|bbj_riken.mpheno24.female|
|name|bbj_riken.mpheno25|
|name|bbj_riken.mpheno25.male|
|name|bbj_riken.mpheno25.female|
|name|bbj_riken.mpheno26|
|name|bbj_riken.mpheno26.male|
|name|bbj_riken.mpheno26.female|
|name|bbj_riken.mpheno27|
|name|bbj_riken.mpheno27.male|
|name|bbj_riken.mpheno27.female|
|name|bbj_riken.mpheno28|
|name|bbj_riken.mpheno28.male|
|name|bbj_riken.mpheno28.female|
|name|bbj_riken.mpheno29|
|name|bbj_riken.mpheno29.male|
|name|bbj_riken.mpheno29.female|
|name|bbj_riken.mpheno30|
|name|bbj_riken.mpheno30.male|
|name|bbj_riken.mpheno30.female|
|name|bbj_riken.mpheno31|
|name|bbj_riken.mpheno31.male|
|name|bbj_riken.mpheno31.female|
|name|bbj_riken.mpheno32|
|name|bbj_riken.mpheno32.male|
|name|bbj_riken.mpheno32.female|
|name|bbj_riken.mpheno33|
|name|bbj_riken.mpheno33.male|
|name|bbj_riken.mpheno33.female|
|name|bbj_riken.mpheno34|
|name|bbj_riken.mpheno34.male|
|name|bbj_riken.mpheno34.female|
|name|bbj_riken.mpheno35|
|name|bbj_riken.mpheno35.male|
|name|bbj_riken.mpheno35.female|
|name|bbj_riken.mpheno36|
|name|bbj_riken.mpheno36.male|
|name|bbj_riken.mpheno36.female|
|name|bbj_riken.mpheno37|
|name|bbj_riken.mpheno37.male|
|name|bbj_riken.mpheno37.female|
|name|bbj_riken.mpheno38|
|name|bbj_riken.mpheno38.male|
|name|bbj_riken.mpheno38.female|
|name|bbj_riken.mpheno39|
|name|bbj_riken.mpheno39.male|
|name|bbj_riken.mpheno39.female|
|name|bbj_riken.mpheno40|
|name|bbj_riken.mpheno40.male|
|name|bbj_riken.mpheno40.female|
|name|bbj_riken.mpheno41|
|name|bbj_riken.mpheno41.female|
|name|bbj_riken.mpheno42|
|name|bbj_riken.mpheno42.female|
|name|bbj_riken.mpheno44|
|name|bbj_riken.mpheno44.male|
|name|bbj_riken.mpheno44.female|
|name|bbj_riken.mpheno45|
|name|bbj_riken.mpheno45.male|
|name|bbj_riken.mpheno45.female|
|name|bbj_riken.mpheno46|
|name|bbj_riken.mpheno46.male|
|name|bbj_riken.mpheno46.female|
|name|tommo|
|name|ncbn|
|name|ncbn.jpn|
|name|ncbn.jpn.hondo|
|name|ncbn.jpn.ryukyu|
|name|ncbn.acb|
|name|ncbn.asw|
|name|ncbn.beb|
|name|ncbn.gbr|
|name|ncbn.cdx|
|name|ncbn.ceu|
|name|ncbn.clm|
|name|ncbn.esn|
|name|ncbn.fin|
|name|ncbn.gwd|
|name|ncbn.gih|
|name|ncbn.chb|
|name|ncbn.chs|
|name|ncbn.ibs|
|name|ncbn.itu|
|name|ncbn.jpt|
|name|ncbn.khv|
|name|ncbn.lwk|
|name|ncbn.msl|
|name|ncbn.mxl|
|name|ncbn.pel|
|name|ncbn.pur|
|name|ncbn.pjl|
|name|ncbn.stu|
|name|ncbn.tsi|
|name|ncbn.yri|
|name|gnomad_genomes|
|name|gnomad_genomes.afr|
|name|gnomad_genomes.ami|
|name|gnomad_genomes.amr|
|name|gnomad_genomes.asj|
|name|gnomad_genomes.eas|
|name|gnomad_genomes.fin|
|name|gnomad_genomes.mid|
|name|gnomad_genomes.nfe|
|name|gnomad_genomes.remaining|
|name|gnomad_genomes.sas|
|name|gnomad_exomes|
|name|gnomad_exomes.afr|
|name|gnomad_exomes.amr|
|name|gnomad_exomes.asj|
|name|gnomad_exomes.eas|
|name|gnomad_exomes.fin|
|name|gnomad_exomes.mid|
|name|gnomad_exomes.nfe|
|name|gnomad_exomes.remaining|
|name|gnomad_exomes.sas|

<h2 id="tocS_Range">Range</h2>
<!-- backwards compatibility -->
<a id="schemarange"></a>
<a id="schema_Range"></a>
<a id="tocSrange"></a>
<a id="tocsrange"></a>

```json
{
  "gte": 0,
  "lte": 0
}

```

Available keys
 * `gte` - Greater than or equal to
 * `te` - Greater than
 * `lte` - Less than or equal to
 * `le` - Less than

### Properties

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Both-closed<br/>(a, b) = {x | a &le; x &le; b}|
|» gte|number|true|none|none|
|» lte|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Both-open<br/>(a, b) = {x | a &lt; x &lt; b}|
|» gt|number|true|none|none|
|» lt|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Left-open, right-closed<br/>(a, b) = {x | a &lt; x &le; b}|
|» gt|number|true|none|none|
|» lte|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Left-closed, right-open<br/>(a, b) = {x | a &le; x &lt; b}|
|» gte|number|true|none|none|
|» lt|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Left-closed, right-unbounded<br/>(a, +&infin;) = {x | x &ge; a}|
|» gte|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Left-open, right-unbounded<br/>(a, +&infin;) = {x | x &gt; a}|
|» gt|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Right-closed, left-unbounded<br/>(-&infin;, b) = {x | x &le; b}|
|» lte|number|true|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|*anonymous*|object|false|none|Right-open, left-unbounded<br/>(-&infin;, b) = {x | x &lt; b}|
|» lt|number|true|none|none|

<h2 id="tocS_And">And</h2>
<!-- backwards compatibility -->
<a id="schemaand"></a>
<a id="schema_And"></a>
<a id="tocSand"></a>
<a id="tocsand"></a>

```json
{
  "and": [
    {
      "id": [
        "string"
      ]
    },
    {
      "id": [
        "string"
      ]
    }
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|and|[oneOf]|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[ID](#schemaid)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Location](#schemalocation)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantType](#schemavarianttype)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantConsequence](#schemavariantconsequence)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantFrequency](#schemavariantfrequency)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Sift](#schemasift)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Polyphen](#schemapolyphen)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[AlphaMissense](#schemaalphamissense)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Gene](#schemagene)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Disease](#schemadisease)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[And](#schemaand)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Or](#schemaor)|false|none|none|

<h2 id="tocS_Or">Or</h2>
<!-- backwards compatibility -->
<a id="schemaor"></a>
<a id="schema_Or"></a>
<a id="tocSor"></a>
<a id="tocsor"></a>

```json
{
  "or": [
    {
      "id": [
        "string"
      ]
    },
    {
      "id": [
        "string"
      ]
    }
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|or|[oneOf]|true|none|none|

oneOf

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[ID](#schemaid)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Location](#schemalocation)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantType](#schemavarianttype)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantConsequence](#schemavariantconsequence)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[VariantFrequency](#schemavariantfrequency)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[ClinicalSignificance](#schemaclinicalsignificance)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Sift](#schemasift)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Polyphen](#schemapolyphen)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[AlphaMissense](#schemaalphamissense)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Gene](#schemagene)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Disease](#schemadisease)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[And](#schemaand)|false|none|none|

xor

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|» *anonymous*|[Or](#schemaor)|false|none|none|

<h2 id="tocS_SearchVariant">SearchVariant</h2>
<!-- backwards compatibility -->
<a id="schemasearchvariant"></a>
<a id="schema_SearchVariant"></a>
<a id="tocSsearchvariant"></a>
<a id="tocssearchvariant"></a>

```json
{
  "scroll": {
    "offset": 0,
    "limit": 0,
    "max_rows": 0
  },
  "statistics": {
    "total": 0,
    "filtered": 0,
    "dataset": {
      "dataset_name": 0
    },
    "type": {
      "so_term": 0
    },
    "significance": {
      "significance_key": 0
    },
    "consequence": {
      "so_term": 0
    }
  },
  "data": [
    {
      "id": "string",
      "type": "string",
      "chromosome": "string",
      "start": 0,
      "stop": 0,
      "reference": "string",
      "alternative": "string",
      "most_severe_consequence": "string",
      "sift": 0,
      "polyphen": 0,
      "existing_variations": [
        "string"
      ],
      "external_link": [
        {
          "db_name": [
            "string"
          ]
        }
      ],
      "significance": [
        {
          "condition": "string",
          "interpretations": [
            "string"
          ]
        }
      ],
      "transcripts": {
        "transcript_id": "string",
        "gene_id": "string",
        "consequence": [
          "string"
        ],
        "sift": 0,
        "polyphen": 0,
        "hgnc_id": 0,
        "symbol": {
          "source": "string",
          "label": "string"
        },
        "hgvs_p": "string",
        "hgvs_c": "string",
        "hgvs_g": "string"
      },
      "frequencies": {
        "source": "string",
        "filter": [
          "string"
        ],
        "quality": 0,
        "allele": {
          "number": 0,
          "count": 0,
          "frequency": 0
        },
        "genotype": {
          "ref_homo_count": 0,
          "hetero_count": 0,
          "alt_homo_count": 0
        }
      }
    }
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|scroll|object|false|none|none|
|» offset|integer|false|none|none|
|» limit|integer|false|none|none|
|» max_rows|integer|false|none|none|
|statistics|object|false|none|none|
|» total|integer|false|none|none|
|» filtered|integer|false|none|none|
|» dataset|object|false|none|none|
|»» dataset_name|integer|false|none|none|
|» type|object|false|none|none|
|»» so_term|integer|false|none|none|
|» significance|object|false|none|none|
|»» significance_key|integer|false|none|none|
|» consequence|object|false|none|none|
|»» so_term|integer|false|none|none|
|data|[object]|false|none|none|
|» id|string|false|none|none|
|» type|string|false|none|none|
|» chromosome|string|false|none|none|
|» start|integer|false|none|none|
|» stop|integer|false|none|none|
|» reference|string|false|none|none|
|» alternative|string|false|none|none|
|» most_severe_consequence|string|false|none|none|
|» sift|number|false|none|none|
|» polyphen|number|false|none|none|
|» existing_variations|[string]|false|none|none|
|» external_link|[object]|false|none|none|
|»» db_name|[string]|false|none|none|
|» significance|[object]|false|none|none|
|»» condition|string|false|none|none|
|»» interpretations|[string]|false|none|none|
|» transcripts|object|false|none|none|
|»» transcript_id|string|false|none|none|
|»» gene_id|string|false|none|none|
|»» consequence|[string]|false|none|none|
|»» sift|number|false|none|none|
|»» polyphen|number|false|none|none|
|»» hgnc_id|integer|false|none|none|
|»» symbol|object|false|none|none|
|»»» source|string|false|none|none|
|»»» label|string|false|none|none|
|»» hgvs_p|string|false|none|none|
|»» hgvs_c|string|false|none|none|
|»» hgvs_g|string|false|none|none|
|» frequencies|object|false|none|none|
|»» source|string|false|none|none|
|»» filter|[string]|false|none|none|
|»» quality|number|false|none|none|
|»» allele|object|false|none|none|
|»»» number|integer|false|none|none|
|»»» count|integer|false|none|none|
|»»» frequency|number|false|none|none|
|»» genotype|object|false|none|none|
|»»» ref_homo_count|integer|false|none|none|
|»»» hetero_count|integer|false|none|none|
|»»» alt_homo_count|integer|false|none|none|

<h2 id="tocS_DownloadVariant">DownloadVariant</h2>
<!-- backwards compatibility -->
<a id="schemadownloadvariant"></a>
<a id="schema_DownloadVariant"></a>
<a id="tocSdownloadvariant"></a>
<a id="tocsdownloadvariant"></a>

```json
{
  "data": [
    {
      "tgv_id": "string",
      "rs": [
        "string"
      ],
      "chromosome": "string",
      "position_grch38": 0,
      "reference": "string",
      "alternate": "string",
      "type": "string",
      "gene": {
        "name": "string",
        "id": "string",
        "synonyms": [
          "string"
        ]
      },
      "consequence": [
        "string"
      ],
      "condition": [
        {}
      ],
      "sift_qualitative_prediction": "string",
      "sift_score": 0,
      "polyphen2_qualitative_prediction": "string",
      "polyphen_score": 0,
      "alphamissense_pathogenicity": "string",
      "alphamissense_score": 0,
      "jga_wgs_allele_alt": 0,
      "jga_wgs_allele_total": 0,
      "jga_wgs_alt_allele_freq": 0,
      "jga_wgs_qc_status": [
        "string"
      ],
      "jga_wes_allele_alt": 0,
      "jga_wes_allele_total": 0,
      "jga_wes_alt_allele_freq": 0,
      "jga_wes_qc_status": [
        "string"
      ],
      "jga_snp_allele_alt": 0,
      "jga_snp_allele_total": 0,
      "jga_snp_alt_allele_freq": 0,
      "jga_snp_genotype_alt_alt": 0,
      "jga_snp_genotype_ref_alt": 0,
      "jga_snp_genotype_ref_ref": 0,
      "jga_snp_qc_status": [
        "string"
      ],
      "tommo_allele_alt": 0,
      "tommo_allele_total": 0,
      "tommo_alt_allele_freq": 0,
      "tommo_qc_status": [
        "string"
      ],
      "hgvd_allele_alt": 0,
      "hgvd_allele_total": 0,
      "hgvd_alt_allele_freq": 0,
      "hgvd_qc_status": [
        "string"
      ],
      "gem_j_wga_allele_alt": 0,
      "gem_j_wga_allele_total": 0,
      "gem_j_wga_alt_allele_freq": 0,
      "gem_j_wga_qc_status": [
        "string"
      ],
      "gnomad_genomes_allele_alt": 0,
      "gnomad_genomes_allele_total": 0,
      "gnomad_genomes_alt_allele_freq": 0,
      "gnomad_genomes_qc_status": [
        "string"
      ]
    }
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|data|[object]|false|none|none|
|» tgv_id|string|false|none|none|
|» rs|[string]|false|none|none|
|» chromosome|string|false|none|none|
|» position_grch38|integer|false|none|none|
|» reference|string|false|none|none|
|» alternate|string|false|none|none|
|» type|string|false|none|none|
|» gene|object|false|none|none|
|»» name|string|false|none|none|
|»» id|string|false|none|none|
|»» synonyms|[string]|false|none|none|
|» consequence|[string]|false|none|none|
|» condition|[object]|false|none|none|
|» sift_qualitative_prediction|string|false|none|none|
|» sift_score|number|false|none|none|
|» polyphen2_qualitative_prediction|string|false|none|none|
|» polyphen_score|number|false|none|none|
|» alphamissense_pathogenicity|string|false|none|none|
|» alphamissense_score|number|false|none|none|
|» jga_wgs_allele_alt|number|false|none|none|
|» jga_wgs_allele_total|number|false|none|none|
|» jga_wgs_alt_allele_freq|number|false|none|none|
|» jga_wgs_qc_status|[string]|false|none|none|
|» jga_wes_allele_alt|number|false|none|none|
|» jga_wes_allele_total|number|false|none|none|
|» jga_wes_alt_allele_freq|number|false|none|none|
|» jga_wes_qc_status|[string]|false|none|none|
|» jga_snp_allele_alt|number|false|none|none|
|» jga_snp_allele_total|number|false|none|none|
|» jga_snp_alt_allele_freq|number|false|none|none|
|» jga_snp_genotype_alt_alt|number|false|none|none|
|» jga_snp_genotype_ref_alt|number|false|none|none|
|» jga_snp_genotype_ref_ref|number|false|none|none|
|» jga_snp_qc_status|[string]|false|none|none|
|» tommo_allele_alt|number|false|none|none|
|» tommo_allele_total|number|false|none|none|
|» tommo_alt_allele_freq|number|false|none|none|
|» tommo_qc_status|[string]|false|none|none|
|» hgvd_allele_alt|number|false|none|none|
|» hgvd_allele_total|number|false|none|none|
|» hgvd_alt_allele_freq|number|false|none|none|
|» hgvd_qc_status|[string]|false|none|none|
|» gem_j_wga_allele_alt|number|false|none|none|
|» gem_j_wga_allele_total|number|false|none|none|
|» gem_j_wga_alt_allele_freq|number|false|none|none|
|» gem_j_wga_qc_status|[string]|false|none|none|
|» gnomad_genomes_allele_alt|number|false|none|none|
|» gnomad_genomes_allele_total|number|false|none|none|
|» gnomad_genomes_alt_allele_freq|number|false|none|none|
|» gnomad_genomes_qc_status|[string]|false|none|none|

<h2 id="tocS_SearchGene">SearchGene</h2>
<!-- backwards compatibility -->
<a id="schemasearchgene"></a>
<a id="schema_SearchGene"></a>
<a id="tocSsearchgene"></a>
<a id="tocssearchgene"></a>

```json
[
  {
    "id": 404,
    "symbol": "ALDH2",
    "name": "aldehyde dehydrogenase 2 family member",
    "alias_of": null,
    "highlight": "<em>ALDH2</em>"
  }
]

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|id|integer|false|none|none|
|symbol|string|false|none|none|
|name|string|false|none|none|
|alias_of|string|false|none|none|
|highlight|string|false|none|none|

<h2 id="tocS_SearchDisease">SearchDisease</h2>
<!-- backwards compatibility -->
<a id="schemasearchdisease"></a>
<a id="schema_SearchDisease"></a>
<a id="tocSsearchdisease"></a>
<a id="tocssearchdisease"></a>

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "highlight": "Hereditary <em>breast</em> and <em>ovarian</em> <em>cancer</em> syndrome"
  }
]

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|id|string|false|none|none|
|cui|string|false|none|none|
|label|string|false|none|none|
|highlight|string|false|none|none|

<h2 id="tocS_InspectDisease">InspectDisease</h2>
<!-- backwards compatibility -->
<a id="schemainspectdisease"></a>
<a id="schema_InspectDisease"></a>
<a id="tocSinspectdisease"></a>
<a id="tocsinspectdisease"></a>

```json
[
  {
    "id": "MONDO_0003582",
    "cui": "C0677776",
    "label": "Hereditary breast and ovarian cancer syndrome",
    "root": false,
    "leaf": false,
    "parents": [
      {
        "id": "MONDO_0016248",
        "cui": "CN201036",
        "label": "Familial ovarian cancer",
        "root": false
      }
    ],
    "children": [
      {
        "id": "MONDO_0012933",
        "cui": "C2675520",
        "label": "Breast-ovarian cancer, familial 2",
        "leaf": true
      }
    ]
  }
]

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|id|string|false|none|none|
|cui|string|false|none|none|
|label|string|false|none|none|
|root|boolean|false|none|none|
|leaf|boolean|false|none|none|
|parents|[object]|false|none|none|
|» id|string|false|none|none|
|» cui|string|false|none|none|
|» label|string|false|none|none|
|» root|boolean|false|none|none|
|children|[object]|false|none|none|
|» id|string|false|none|none|
|» cui|string|false|none|none|
|» label|string|false|none|none|
|» leaf|boolean|false|none|none|

<h2 id="tocS_Error">Error</h2>
<!-- backwards compatibility -->
<a id="schemaerror"></a>
<a id="schema_Error"></a>
<a id="tocSerror"></a>
<a id="tocserror"></a>

```json
{
  "errors": [
    "error message"
  ]
}

```

### Properties

|Name|Type|Required|Restrictions|Description|
|---|---|---|---|---|
|errors|[string]|false|none|none|

